Welcome to pipeasy-spark's documentation!
======================================

`pipeasy-spark` is a Python package designed to help you prepare 
your pyspark dataframe for a machine learning task performed by 
the `spark ML library <https://spark.apache.org/docs/latest/ml-guide.html/>`_.

Check out `the repository on Github <https://github.com/Quantmetry/pipeasy-spark/>`_

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   usage
   modules
   contributing
   history

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
